@@ -1,3 +1,74 @@
+#' Check species names against the ITIS taxonomic database
+#' 
+#' The function checks species names (common or scientific names) provided by
+#' the user with the ITIS taxonomic database (\url{http://www.itis.gov/}) via
+#' functions from the package \pkg{taxize}. It returns both common and
+#' scientific names, the taxon authors, taxon rank name and status, the TSN
+#' (taxonomic serial numbers) and ITIS urls.
+#' 
+#' Arguments \code{searchtype}, \code{accepted} and \code{ask} are passed on to
+#' \code{\link[taxize]{get_tsn}}.
+#' 
+#' @param speciesNames character. Vector of species names to check. Either
+#' common names or scientific names.
+#' @param searchtype character. Type of names specified in \code{speciesNames}.
+#' One of 'scientific' or 'common'.
+#' @param accepted logical. Return only accepted valid names? If TRUE, invalid
+#' names are returned as NA. Set to FALSE to return both accepted and
+#' unaccepted names.
+#' @param ask logical. Should the function be run in interactive mode? If TRUE
+#' and more than one TSN is found for a species, the user is asked to choose
+#' one. If FALSE, NA is returned for multiple matches.
+#' @return A \code{data.frame} with the names supplied by the user, matching
+#' common and scientific names, taxon author and year, taxonomic rank, status,
+#' TSNs (taxonomic serial numbers) and ITIS urls.
+#' 
+#' @author Juergen Niedballa
+#' 
+#' @references \url{http://www.itis.gov/}
+#' 
+#' @examples
+#' 
+#' 
+#' \dontrun{
+#' 
+#' 
+#' species_common <- c("Leopard Cat", "moonrat")
+#' 
+#' # ask = TRUE. Multiple matches for leopard cat will cause menu to pop up asking user input.
+#' 
+#' species.names.check1 <- checkSpeciesNames(speciesNames = species_common,
+#'                                           searchtype   = "common",
+#'                                           accepted     = TRUE,
+#'                                           ask          = TRUE)
+#' 2   # we choose entry 2
+#' species.names.check1
+#' 
+#' 
+#' # ask = FALSE. Multiple matches for leopard cat will cause NA.
+#' 
+#' species.names.check2 <- checkSpeciesNames(speciesNames = species_common,
+#'                                           searchtype   = "common",
+#'                                           accepted     = TRUE,
+#'                                           ask          = FALSE)
+#' species.names.check2
+#' 
+#' 
+#' 
+#' # search for scientific names
+#' 
+#' species_scientific <- c("Tragulus", "Prionailurus bengalensis")
+#' 
+#' species.names.check3 <- checkSpeciesNames(speciesNames = species_scientific,
+#'                                           searchtype   = "scientific",
+#'                                           accepted     = TRUE,
+#'                                           ask          = TRUE)
+#' species.names.check3
+#' }
+#' 
+#' 
+#' @export checkSpeciesNames
+#' 
 checkSpeciesNames <- function(speciesNames,
                               searchtype,
                               accepted = TRUE,
@@ -20,7 +91,7 @@ checkSpeciesNames <- function(speciesNames,
 
   # query ITIS TSN (taxnonomic serial number)
   tsns <- try(
-    taxize::get_tsn(searchterm = speciesNames,
+    taxize::get_tsn(sci_com    = speciesNames,
                     searchtype = searchtype,
                     accepted   = accepted,
                     ask        = ask,
@@ -130,7 +201,9 @@ checkSpeciesNames <- function(speciesNames,
       dat.out$taxon_status[!is.na(dat.out$tsn)]  <- "valid"
     }
 
-    return(dat.out)
+    dat.out.sorted <- dat.out[match(dat.out$user_name, speciesNames),]
+    
+    return(dat.out.sorted)
 
   } else {stop("found no TSNs for speciesNames", call. = FALSE)}   # error if no tsns found
-}
\ No newline at end of file
+}
